@@ -97,15 +97,13 @@ def test_wcs(aia171_test_map):
 
     assert all(wcs.wcs.crpix ==
                [aia171_test_map.reference_pixel.x.value, aia171_test_map.reference_pixel.y.value])
-    assert all(wcs.wcs.cdelt == [aia171_test_map.scale.axis1.value,
-                                 aia171_test_map.scale.axis1.value])
-    assert all(
-        wcs.wcs.crval ==
-        [aia171_test_map._reference_longitude.value, aia171_test_map._reference_latitude.value])
+    assert u.allclose(wcs.wcs.cdelt * (u.Unit(wcs.wcs.cunit[0])/u.pix),
+                      u.Quantity(aia171_test_map.scale))
+    assert u.allclose(wcs.wcs.crval * u.Unit(wcs.wcs.cunit[0]),
+                      u.Quantity([aia171_test_map._reference_longitude, aia171_test_map._reference_latitude]))
     assert set(wcs.wcs.ctype) == {
         aia171_test_map.coordinate_system.axis1, aia171_test_map.coordinate_system.axis2}
     np.testing.assert_allclose(wcs.wcs.pc, aia171_test_map.rotation_matrix)
-    assert set(wcs.wcs.cunit) == {u.Unit(a) for a in aia171_test_map.spatial_units}
 
 
 def test_no_observer_wcs(heliographic_test_map):
@@ -113,13 +111,6 @@ def test_no_observer_wcs(heliographic_test_map):
     assert not hasattr(heliographic_test_map.wcs, "heliographic_observer")
 
 
-def test_header_immutability(aia171_test_map):
-    # Check that accessing the wcs of a map doesn't modify the meta data
-    assert 'KEYCOMMENTS' in aia171_test_map.meta
-    wcs = aia171_test_map.wcs
-    assert 'KEYCOMMENTS' in aia171_test_map.meta
-
-
 def test_dtype(generic_map):
     assert generic_map.dtype == np.float64
 
@@ -211,6 +202,10 @@ def test_units(generic_map):
     generic_map.spatial_units == ('arcsec', 'arcsec')
 
 
+def test_cmap(generic_map):
+    assert generic_map.cmap == plt.get_cmap('gray')
+
+
 def test_coordinate_frame(aia171_test_map):
     frame = aia171_test_map.coordinate_frame
     assert isinstance(frame, sunpy.coordinates.Helioprojective)
@@ -390,15 +385,13 @@ def test_shift_history(generic_map):
     assert resultant_shift[1] == y_shift1 + y_shift2
 
 
-# Check that submap works with units convertable to pix but that aren't pix
-@pytest.mark.parametrize('unit', [u.pix, u.mpix * 1e3])
-def test_submap(generic_map, unit):
+def test_submap(generic_map):
     """Check data and header information for a submap"""
     width = generic_map.data.shape[1]
     height = generic_map.data.shape[0]
 
     # Create a submap of the top-right quadrant of the image
-    submap = generic_map.submap([width / 2., height / 2.] * unit, [width, height] * unit)
+    submap = generic_map.submap([width / 2., height / 2.] * u.pix, [width, height] * u.pix)
 
     # Check to see if submap properties were updated properly
     assert submap.reference_pixel.x.value == generic_map.meta['crpix1'] - width / 2.
@@ -578,7 +571,7 @@ def test_rotate_new_matrix(generic_map):
 
 
 def test_rotate_rmatrix_angle(generic_map):
-    with pytest.raises(ValueError):
+    with pytest.raises(TypeError):
         generic_map.rotate(angle=5, rmatrix=np.array([[1, 0], [0, 1]]))
 
 
@@ -728,6 +721,31 @@ def test_fits_header(aia171_test_map):
     assert isinstance(aia171_test_map.fits_header, fits.Header)
 
 
+def test_bad_coordframe_repr(generic_map):
+    generic_map.meta['CTYPE1'] = "STUART1"
+    generic_map.meta['CTYPE2'] = "STUART2"
+    assert 'Unknown' in generic_map.__repr__()
+
+
+def test_bad_header_final_fallback():
+    # Checks that if a WCS cannot be constructed from the
+    # header, a warning is raised and a simple WCS is created
+    # instead
+    header = {'cunit1': 'arcsec',
+              'cunit2': 'arcsec',
+              None: None,  # Cannot parse this into WCS
+              }
+    m = sunpy.map.GenericMap(np.zeros((10, 10)), header)
+    with pytest.warns(UserWarning,
+                      match="Unable to treat `.meta` as a FITS header, assuming a simple WCS."):
+        m.wcs
+    # Simple WCS validation
+    assert list(m.wcs.wcs.ctype) == ['HPLN-', 'HPLT-']
+    assert (m.wcs.wcs.crval == [0.0, 0.0]).all()
+    assert (m.wcs.wcs.crpix == [5.5, 5.5]).all()
+    assert (m.wcs.wcs.cdelt == [1.0, 1.0]).all()
+
+
 def test_wcs_isot(aia171_test_map):
     # Check that a Map WCS returns the time as isot format
     assert aia171_test_map.wcs.to_header()['DATE-OBS'] == '2011-02-15T00:00:00.340'
